simplify.AuthenticationError

Package simplify :: Class AuthenticationError |
[hide private]
[frames] | no frames]

# Class AuthenticationError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            ApiError --+
                                       |
                                      AuthenticationError

Error raised where there are problems authentication a request.

Instance Methods | [hide private]
Inherited from `ApiError`: `__init__`, `describe` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables | [hide private]
Inherited from `ApiError`: `error_code`, `error_data`, `message`, `reference`, `status`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`